[![Build Status](https://travis-ci.org/Terralego/django-terra-settings.svg?branch=master)](https://travis-ci.org/Terralego/django-terra-settings)
[![codecov](https://codecov.io/gh/Terralego/django-terra-settings/branch/master/graph/badge.svg)](https://codecov.io/gh/Terralego/django-terra-settings)
[![Maintainability](https://api.codeclimate.com/v1/badges/186dad418b5c5cdb9cf8/maintainability)](https://codeclimate.com/github/Terralego/django-terra-settings/maintainability)


https://django-terra-settings.readthedocs.io/en/latest/

Helpers and default configuration endpoints for terralego application.
